@@ -33,6 +33,7 @@ WebhookTypesLiterals = Literal[
     'entity_verification_session.update',
     'connect.create',
     'connect.update',
+    'connect.available',
     'balance.create',
     'balance.update',
     'identity.create',
@@ -41,6 +42,7 @@ WebhookTypesLiterals = Literal[
     'account_verification_session.update',
     'card_brand.create',
     'card_brand.update',
+    'card_brand.available',
     'sensitive.create',
     'sensitive.update',
     'update.create',
@@ -65,6 +67,8 @@ WebhookTypesLiterals = Literal[
     'attribute.credit_health_payment_history.decreased',
     'attribute.credit_health_open_accounts.increased',
     'attribute.credit_health_open_accounts.decreased',
+    'method_jwk.create',
+    'method_jwk.update',
 ]
 
 
@@ -89,6 +93,10 @@ class WebhookCreateOpts(TypedDict):
     expand_event: Optional[bool]
 
 
+class WebhookUpdateOpts(TypedDict):
+    status: Optional[str]
+
+
 class WebhookResource(Resource):
     def __init__(self, config: Configuration):
         super(WebhookResource, self).__init__(config.add_path('webhooks'))
@@ -105,3 +113,6 @@ class WebhookResource(Resource):
 
     def create(self, opts: WebhookCreateOpts, request_opts: Optional[RequestOpts] = None) -> MethodResponse[Webhook]:
         return super(WebhookResource, self)._create(opts, request_opts)
+    
+    def update(self, _id: str, opts: WebhookUpdateOpts) -> MethodResponse[Webhook]:
+        return super(WebhookResource, self)._patch_with_id(_id, opts)
